==> flask-ligand-example-0.4.0.tar.gz: flask-ligand-example-0.4.0/CHANGELOG.md <==
Changelog
=========

<!--next-version-placeholder-->

## v0.4.0 (2022-10-07)
### Feature
* [511:sparkles:] Fix OIDC IAM Provider Configuration ([`7e3b44e`](https://github.com/cowofevil/flask-ligand-example/commit/7e3b44edb5c8dd0590f1060a081e966d58a505a1))

### Other
* Build(deps-dev): update pytest-mock requirement from ~=3.8 to ~=3.10 ([`da8dc29`](https://github.com/cowofevil/flask-ligand-example/commit/da8dc29d34b4da8f1dd5a988c5781caadef9a260))
* Build(deps-dev): update black requirement from ~=22.8 to ~=22.10 ([`72c759e`](https://github.com/cowofevil/flask-ligand-example/commit/72c759e8b97bf0bc650edf1ef9dd5a833413b191))

## v0.3.0 (2022-10-07)
### Feature
* [500:sparkles:] Add Auth0 Support ([`021a7af`](https://github.com/cowofevil/flask-ligand-example/commit/021a7afa744d174866d7f2ae3b7f073328a7117f))

### Other
* Build(deps-dev): update mypy requirement from ~=0.971 to ~=0.982 ([`e07ee70`](https://github.com/cowofevil/flask-ligand-example/commit/e07ee70f74b70d831b2d2693eca7659c589b2a0d))
* Build(deps-dev): update coverage[toml] requirement from ~=6.4 to ~=6.5 ([`f51e40c`](https://github.com/cowofevil/flask-ligand-example/commit/f51e40c140b41c3637e5ee4c5292ea3a08f82834))
* Build(deps-dev): update pytest-cov requirement from ~=3.0 to ~=4.0 ([`3459089`](https://github.com/cowofevil/flask-ligand-example/commit/3459089cead1eda65f6e863aa8b274dbc76883a9))
* Build(deps-dev): update types-setuptools requirement ([`176d24b`](https://github.com/cowofevil/flask-ligand-example/commit/176d24b6f7455f23cd95a1c54d8cbce6eb421728))
* [pre-commit.ci] pre-commit autoupdate ([`f8ee341`](https://github.com/cowofevil/flask-ligand-example/commit/f8ee341fe080a8ab231b4983d09e747e3b2a8d17))
* Build(deps-dev): update tox requirement from ~=3.25 to ~=3.26 ([`590a29f`](https://github.com/cowofevil/flask-ligand-example/commit/590a29f6e89e1c42125542c66ddbf6f47a833d9c))
* Build(deps-dev): update pipdeptree requirement from ~=2.2 to ~=2.3 ([`e92deba`](https://github.com/cowofevil/flask-ligand-example/commit/e92debae8536f29d6784e38c60db0c3cd1e2739d))
* Build(deps-dev): update ipython requirement from ~=8.4 to ~=8.5 ([`1de8d24`](https://github.com/cowofevil/flask-ligand-example/commit/1de8d24da5197e65dd5a394f7359e8534e1a1843))

## v0.2.0 (2022-09-21)
### :sparkles:
* [FIX:sparkles:] Update to flask-ligand v0.4.0 ([`ea3e349`](https://github.com/cowofevil/flask-ligand-example/commit/ea3e349c3df2860629426ce79377e20610199862))

## v0.1.1 (2022-09-14)
### :robot:
* [538:robot:] Enable Publishing Package to PyPI ([`7a99d03`](https://github.com/cowofevil/flask-ligand-example/commit/7a99d0379972e9dafea1b4ce130e0c180e0552d2))

### Other
* Merge pull request #5 from cowofevil/cowofevil/sc-538/quickstart-with-simple-working-example ([`e07fd6b`](https://github.com/cowofevil/flask-ligand-example/commit/e07fd6bc84a2ad0ac7f85e38cafa4ab35b7b38da))

## v0.1.0 (2022-09-13)
### :sparkles:
* [FIX:sparkles:] Remove Unnecessary Docs and Publish a Release ([`3e5940e`](https://github.com/cowofevil/flask-ligand-example/commit/3e5940e81884f554d1b2514ff7f4c907e3a2cf63))

### Other
* [538] Example Project Tutorial ([`221191c`](https://github.com/cowofevil/flask-ligand-example/commit/221191c182c28208e44350b6faea899306aee9d1))
* Initial commit ([`1695158`](https://github.com/cowofevil/flask-ligand-example/commit/1695158821591356b21575575031493a4b5882f4))

==> flask-ligand-example-0.4.1.tar.gz: flask-ligand-example-0.4.1/CHANGELOG.md <==
Changelog
=========

<!--next-version-placeholder-->

## v0.4.1 (2022-10-18)
### Fix
* [543:robot:] Refactor for flask-smorest Etag Changes ([`7718f40`](https://github.com/cowofevil/flask-ligand-example/commit/7718f401d7464fd7ecd56dee3d8fa72695680434))

## v0.4.0 (2022-10-07)
### Feature
* [511:sparkles:] Fix OIDC IAM Provider Configuration ([`7e3b44e`](https://github.com/cowofevil/flask-ligand-example/commit/7e3b44edb5c8dd0590f1060a081e966d58a505a1))

### Other
* Build(deps-dev): update pytest-mock requirement from ~=3.8 to ~=3.10 ([`da8dc29`](https://github.com/cowofevil/flask-ligand-example/commit/da8dc29d34b4da8f1dd5a988c5781caadef9a260))
* Build(deps-dev): update black requirement from ~=22.8 to ~=22.10 ([`72c759e`](https://github.com/cowofevil/flask-ligand-example/commit/72c759e8b97bf0bc650edf1ef9dd5a833413b191))

## v0.3.0 (2022-10-07)
### Feature
* [500:sparkles:] Add Auth0 Support ([`021a7af`](https://github.com/cowofevil/flask-ligand-example/commit/021a7afa744d174866d7f2ae3b7f073328a7117f))

### Other
* Build(deps-dev): update mypy requirement from ~=0.971 to ~=0.982 ([`e07ee70`](https://github.com/cowofevil/flask-ligand-example/commit/e07ee70f74b70d831b2d2693eca7659c589b2a0d))
* Build(deps-dev): update coverage[toml] requirement from ~=6.4 to ~=6.5 ([`f51e40c`](https://github.com/cowofevil/flask-ligand-example/commit/f51e40c140b41c3637e5ee4c5292ea3a08f82834))
* Build(deps-dev): update pytest-cov requirement from ~=3.0 to ~=4.0 ([`3459089`](https://github.com/cowofevil/flask-ligand-example/commit/3459089cead1eda65f6e863aa8b274dbc76883a9))
* Build(deps-dev): update types-setuptools requirement ([`176d24b`](https://github.com/cowofevil/flask-ligand-example/commit/176d24b6f7455f23cd95a1c54d8cbce6eb421728))
* [pre-commit.ci] pre-commit autoupdate ([`f8ee341`](https://github.com/cowofevil/flask-ligand-example/commit/f8ee341fe080a8ab231b4983d09e747e3b2a8d17))
* Build(deps-dev): update tox requirement from ~=3.25 to ~=3.26 ([`590a29f`](https://github.com/cowofevil/flask-ligand-example/commit/590a29f6e89e1c42125542c66ddbf6f47a833d9c))
* Build(deps-dev): update pipdeptree requirement from ~=2.2 to ~=2.3 ([`e92deba`](https://github.com/cowofevil/flask-ligand-example/commit/e92debae8536f29d6784e38c60db0c3cd1e2739d))
* Build(deps-dev): update ipython requirement from ~=8.4 to ~=8.5 ([`1de8d24`](https://github.com/cowofevil/flask-ligand-example/commit/1de8d24da5197e65dd5a394f7359e8534e1a1843))

## v0.2.0 (2022-09-21)
### :sparkles:
* [FIX:sparkles:] Update to flask-ligand v0.4.0 ([`ea3e349`](https://github.com/cowofevil/flask-ligand-example/commit/ea3e349c3df2860629426ce79377e20610199862))

## v0.1.1 (2022-09-14)
### :robot:
* [538:robot:] Enable Publishing Package to PyPI ([`7a99d03`](https://github.com/cowofevil/flask-ligand-example/commit/7a99d0379972e9dafea1b4ce130e0c180e0552d2))

### Other
* Merge pull request #5 from cowofevil/cowofevil/sc-538/quickstart-with-simple-working-example ([`e07fd6b`](https://github.com/cowofevil/flask-ligand-example/commit/e07fd6bc84a2ad0ac7f85e38cafa4ab35b7b38da))

## v0.1.0 (2022-09-13)
### :sparkles:
* [FIX:sparkles:] Remove Unnecessary Docs and Publish a Release ([`3e5940e`](https://github.com/cowofevil/flask-ligand-example/commit/3e5940e81884f554d1b2514ff7f4c907e3a2cf63))

### Other
* [538] Example Project Tutorial ([`221191c`](https://github.com/cowofevil/flask-ligand-example/commit/221191c182c28208e44350b6faea899306aee9d1))
* Initial commit ([`1695158`](https://github.com/cowofevil/flask-ligand-example/commit/1695158821591356b21575575031493a4b5882f4))
